@@ -10,7 +10,7 @@ class NetworkParentActor(Actor):
         super().__init__(*args, **kwargs)
 
     def set_network_throttling(self, download_throughput: int, upload_throughput: int, latency_ms: int):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "setNetworkThrottling",
             "options": {
@@ -21,26 +21,26 @@ class NetworkParentActor(Actor):
         })
 
     def get_network_throttling(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "getNetworkThrottling",
         })
 
     def clear_network_throttling(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "clearNetworkThrottling",
         })
 
     def set_blocked_urls(self, urls : List[str]):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "setBlockedUrls",
             "urls": urls,
         })
 
     def get_blocked_urls(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "getBlockedUrls",
         })
