@@ -9,13 +9,13 @@ class ContentProcessActor(Actor):
         super().__init__(*args, **kwargs)
 
     def list_workers(self):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "listWorkers",
         }, "workers")
 
     def pause_matching_service_workers(self, origin = ""):
-        return self.client.request_response({
+        return self.client.send_receive({
             "to": self.actor_id,
             "type": "pauseMatchingServiceWorkers",
             "origin": origin,
